@@ -1,6 +1,6 @@
 package POE::Filter::IRCv3;
 {
-  $POE::Filter::IRCv3::VERSION = '0.042002';
+  $POE::Filter::IRCv3::VERSION = '0.042003';
 }
 
 use strictures 1;
@@ -235,7 +235,7 @@ POE::Filter::IRCv3 - IRCv3.2 parser without regular expressions
 
 =head1 SYNOPSIS
 
-  my $filter = IRC::Server::Pluggable::IRC::Filter->new(colonify => 1);
+  my $filter = POE::Filter::IRCv3->new(colonify => 1);
 
   # Raw lines parsed to hashes:
   my $array_of_refs  = $filter->get( [ $line1, $line ... ] );
@@ -246,7 +246,7 @@ POE::Filter::IRCv3 - IRCv3.2 parser without regular expressions
 
   # Stacked with a line filter, suitable for Wheel usage, etc:
 
-  my $ircd = IRC::Server::Pluggable::IRC::Filter->new(colonify => 1);
+  my $ircd = POE::Filter::IRCv3->new(colonify => 1);
 
   my $line = POE::Filter::Line->new(
     InputRegexp   => '\015?\012',
